Module: ArCache::ActiveRecord::Core::ClassMethods
- Defined in:
- lib/ar_cache/active_record/core.rb
Instance Method Summary collapse
-
#find ⇒ Object
The #find use statement cache execute querying first, so need force skip.
-
#find_by ⇒ Object
The #find_by use statement cache execute querying first, so need force skip.